=======
Credits
=======

This project started as a fork of `bradeion`_.

.. _django-admin-export: https://github.com/burke-software/django-admin-export

Development Lead
----------------

* Fernando Macedo <fgmacedo@gmail.com>

Contributors
------------

None yet. Why not be the first?


Tools
---------

Tools used in rendering this package:

*  Cookiecutter_
*  `cookiecutter-djangopackage`_

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`cookiecutter-djangopackage`: https://github.com/pydanny/cookiecutter-djangopackage
